        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260603 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260603 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 31 <strong>control</strong><br>0,1,2,3,4,6,11,12,13,18,19,20,24,27,29,30,31,32,34,36,37,39,40,41,43,44,45,47,48,49,50';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260603 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 20 <br>5,7,8,9,10,14,15,16,17,21,22,23,25,26,28,33,35,38,42,46';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260603 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260603 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 31 <strong>control</strong><br>0,1,2,3,4,6,11,12,13,18,19,20,24,27,29,30,31,32,34,36,37,39,40,41,43,44,45,47,48,49,50';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260603 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 20 <br>5,7,8,9,10,14,15,16,17,21,22,23,25,26,28,33,35,38,42,46';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260603 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260603 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 31 <strong>control</strong><br>0,1,2,3,4,6,11,12,13,18,19,20,24,27,29,30,31,32,34,36,37,39,40,41,43,44,45,47,48,49,50';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260603 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 20 <br>5,7,8,9,10,14,15,16,17,21,22,23,25,26,28,33,35,38,42,46';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260603 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260603 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 31 <strong>control</strong><br>0,1,2,3,4,6,11,12,13,18,19,20,24,27,29,30,31,32,34,36,37,39,40,41,43,44,45,47,48,49,50';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260603 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 20 <br>5,7,8,9,10,14,15,16,17,21,22,23,25,26,28,33,35,38,42,46';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260603 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260603 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 31 <strong>control</strong><br>0,1,2,3,4,6,11,12,13,18,19,20,24,27,29,30,31,32,34,36,37,39,40,41,43,44,45,47,48,49,50';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260603 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 20 <br>5,7,8,9,10,14,15,16,17,21,22,23,25,26,28,33,35,38,42,46';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260603 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260603 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 31 <strong>control</strong><br>0,1,2,3,4,6,11,12,13,18,19,20,24,27,29,30,31,32,34,36,37,39,40,41,43,44,45,47,48,49,50';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260603 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>23</strong> miembros: 20 <br>5,7,8,9,10,14,15,16,17,21,22,23,25,26,28,33,35,38,42,46';}
}
